@@ -33,17 +33,19 @@ import org.apache.hc.client5.http.classic.methods.HttpPost;
 import org.apache.hc.client5.http.protocol.HttpClientContext;
 import org.apache.hc.core5.http.HttpException;
 import org.apache.hc.core5.http.HttpHeaders;
+import org.apache.hc.core5.http.HttpHost;
 import org.apache.hc.core5.http.HttpResponse;
 import org.apache.hc.core5.http.HttpStatus;
 import org.apache.hc.core5.http.ProtocolException;
 import org.apache.hc.core5.http.message.BasicHttpResponse;
+import org.apache.hc.core5.http.support.BasicRequestBuilder;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
-public class TestDefaultRedirectStrategy {
+class TestDefaultRedirectStrategy {
 
     @Test
-    public void testIsRedirectedMovedTemporary() throws Exception {
+    void testIsRedirectedMovedTemporary() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -54,7 +56,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedMovedTemporaryNoLocation() throws Exception {
+    void testIsRedirectedMovedTemporaryNoLocation() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -63,7 +65,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedMovedPermanently() throws Exception {
+    void testIsRedirectedMovedPermanently() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -74,7 +76,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedTemporaryRedirect() throws Exception {
+    void testIsRedirectedTemporaryRedirect() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -85,7 +87,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedSeeOther() throws Exception {
+    void testIsRedirectedSeeOther() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -96,7 +98,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedUnknownStatus() throws Exception {
+    void testIsRedirectedUnknownStatus() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -107,7 +109,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testIsRedirectedInvalidInput() throws Exception {
+    void testIsRedirectedInvalidInput() {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -119,7 +121,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUri() throws Exception {
+    void testGetLocationUri() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -130,7 +132,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriMissingHeader() throws Exception {
+    void testGetLocationUriMissingHeader() {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -140,7 +142,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriInvalidLocation() throws Exception {
+    void testGetLocationUriInvalidLocation() {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -151,7 +153,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriRelative() throws Exception {
+    void testGetLocationUriRelative() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -162,7 +164,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriRelativeWithFragment() throws Exception {
+    void testGetLocationUriRelativeWithFragment() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -173,7 +175,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriAbsoluteWithFragment() throws Exception {
+    void testGetLocationUriAbsoluteWithFragment() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -184,7 +186,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriNormalized() throws Exception {
+    void testGetLocationUriNormalized() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -195,7 +197,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testGetLocationUriInvalidInput() throws Exception {
+    void testGetLocationUriInvalidInput() {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet httpget = new HttpGet("http://localhost/");
@@ -210,21 +212,21 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testCreateLocationURI() throws Exception {
+    void testCreateLocationURI() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         Assertions.assertEquals("http://blahblah/",
                 redirectStrategy.createLocationURI("http://BlahBlah").toASCIIString());
     }
 
     @Test
-    public void testCreateLocationURIInvalid() throws Exception {
+    void testCreateLocationURIInvalid() {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         Assertions.assertThrows(ProtocolException.class, () ->
                 redirectStrategy.createLocationURI(":::::::"));
     }
 
     @Test
-    public void testResolveRelativeLocation() throws Exception {
+    void testResolveRelativeLocation() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet request = new HttpGet("http://localhost/");
@@ -237,7 +239,7 @@ public class TestDefaultRedirectStrategy {
     }
 
     @Test
-    public void testUseAbsoluteLocation() throws Exception {
+    void testUseAbsoluteLocation() throws Exception {
         final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
         final HttpClientContext context = HttpClientContext.create();
         final HttpGet request = new HttpGet("http://localhost/");
@@ -249,4 +251,77 @@ public class TestDefaultRedirectStrategy {
         Assertions.assertEquals(URI.create("http://localhost/foo;bar=baz"), locationURI);
     }
 
+    @Test
+    void testRedirectAllowed() throws Exception {
+        final DefaultRedirectStrategy redirectStrategy = new DefaultRedirectStrategy();
+
+        Assertions.assertTrue(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 1234),
+                BasicRequestBuilder.get("/").build(),
+                null));
+
+        Assertions.assertTrue(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 1234),
+                BasicRequestBuilder.get("/")
+                        .build(),
+                null));
+
+        Assertions.assertTrue(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 1234),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.AUTHORIZATION, "let me pass")
+                        .build(),
+                null));
+
+        Assertions.assertTrue(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 1234),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.COOKIE, "stuff=blah")
+                        .build(),
+                null));
+
+        Assertions.assertTrue(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("someotherhost", 1234),
+                BasicRequestBuilder.get("/")
+                        .build(),
+                null));
+
+        Assertions.assertFalse(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("someotherhost", 1234),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.AUTHORIZATION, "let me pass")
+                        .build(),
+                null));
+
+        Assertions.assertFalse(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("someotherhost", 1234),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.COOKIE, "stuff=blah")
+                        .build(),
+                null));
+
+        Assertions.assertFalse(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 80),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.AUTHORIZATION, "let me pass")
+                        .build(),
+                null));
+
+        Assertions.assertFalse(redirectStrategy.isRedirectAllowed(
+                new HttpHost("somehost", 1234),
+                new HttpHost("somehost", 80),
+                BasicRequestBuilder.get("/")
+                        .addHeader(HttpHeaders.COOKIE, "stuff=blah")
+                        .build(),
+                null));
+    }
+
 }
